Exception: Pgoutput::UnknownRelationError

Inherits:
Error
  • Object
show all
Defined in:
lib/pgoutput/errors.rb

Overview

Raised when row data references a relation id that has not been observed via a preceding Relation (‘R`) message in the current stream decoder.